@@ -63,6 +63,8 @@ def filters(dbname, exception_type, regex):
 @filters("mysql", sqla_exc.InternalError, r"^.*\b1213\b.*Deadlock found.*")
 @filters("mysql", sqla_exc.InternalError,
          r"^.*\b1213\b.*detected deadlock/conflict.*")
+@filters("mysql", sqla_exc.InternalError,
+         r"^.*\b1213\b.*Deadlock: wsrep aborted.*")
 @filters("postgresql", sqla_exc.OperationalError, r"^.*deadlock detected.*")
 @filters("postgresql", sqla_exc.DBAPIError, r"^.*deadlock detected.*")
 @filters("ibm_db_sa", sqla_exc.DBAPIError, r"^.*SQL0911N.*")
@@ -193,15 +195,16 @@ def _sqlite_dupe_key_error(integrity_error, match, engine_name, is_disconnect):
          r"(?i).*foreign key constraint failed")
 @filters("postgresql", sqla_exc.IntegrityError,
          r".*on table \"(?P<table>[^\"]+)\" violates "
-         "foreign key constraint \"(?P<constraint>[^\"]+)\".*\n"
-         "DETAIL:  Key \((?P<key>.+)\)=\(.+\) "
-         "is (not present in|still referenced from) table "
-         "\"(?P<key_table>[^\"]+)\".")
-@filters("mysql", sqla_exc.IntegrityError,
-         r".*Cannot (add|delete) or update a (child|parent) row: "
-         'a foreign key constraint fails \([`"].+[`"]\.[`"](?P<table>.+)[`"], '
-         'CONSTRAINT [`"](?P<constraint>.+)[`"] FOREIGN KEY '
-         '\([`"](?P<key>.+)[`"]\) REFERENCES [`"](?P<key_table>.+)[`"] ')
+         r"foreign key constraint \"(?P<constraint>[^\"]+)\".*\n"
+         r"DETAIL:  Key \((?P<key>.+)\)=\(.+\) "
+         r"is (not present in|still referenced from) table "
+         r"\"(?P<key_table>[^\"]+)\".")
+@filters(
+    "mysql", sqla_exc.IntegrityError,
+    r".*Cannot (add|delete) or update a (child|parent) row: "
+    r'a foreign key constraint fails \([`"].+[`"]\.[`"](?P<table>.+)[`"], '
+    r'CONSTRAINT [`"](?P<constraint>.+)[`"] FOREIGN KEY '
+    r'\([`"](?P<key>.+)[`"]\) REFERENCES [`"](?P<key_table>.+)[`"] ')
 def _foreign_key_error(integrity_error, match, engine_name, is_disconnect):
     """Filter for foreign key errors."""
 
@@ -251,11 +254,11 @@ def _check_constraint_error(
          "of relation "
          "\"(?P<relation>.+)\" does not exist")
 @filters("mysql", sqla_exc.InternalError,
-         r".*1091,.*Can't DROP '(?P<constraint>.+)'; "
-         "check that column/key exists")
+         r".*1091,.*Can't DROP (?:FOREIGN KEY )?['`](?P<constraint>.+)['`]; "
+         "check that .* exists")
 @filters("mysql", sqla_exc.OperationalError,
-         r".*1091,.*Can't DROP '(?P<constraint>.+)'; "
-         "check that column/key exists")
+         r".*1091,.*Can't DROP (?:FOREIGN KEY )?['`](?P<constraint>.+)['`]; "
+         "check that .* exists")
 @filters("mysql", sqla_exc.InternalError,
          r".*1025,.*Error on rename of '.+/(?P<relation>.+)' to ")
 def _check_constraint_non_existing(
@@ -410,8 +413,7 @@ def _raise_for_remaining_DBAPIError(error, match, engine_name, is_disconnect):
     if is_disconnect:
         raise exception.DBConnectionError(error)
     else:
-        LOG.exception(
-            'DBAPIError exception wrapped from %s' % error)
+        LOG.warn('DBAPIError exception wrapped.', exc_info=True)
         raise exception.DBError(error)
 
 
@@ -422,9 +424,10 @@ def _raise_for_unicode_encode(error, match, engine_name, is_disconnect):
 
 @filters("*", Exception, r".*")
 def _raise_for_all_others(error, match, engine_name, is_disconnect):
-    LOG.exception('DB exception wrapped.')
+    LOG.warn('DB exception wrapped.', exc_info=True)
     raise exception.DBError(error)
 
+
 ROLLBACK_CAUSE_KEY = 'oslo.db.sp_rollback_cause'
 
 
@@ -475,11 +478,11 @@ def handler(context):
                                 if isinstance(
                                         dbe, exception.DBConnectionError):
                                     context.is_disconnect = True
-                                raise
+                                return dbe
 
 
 def register_engine(engine):
-    event.listen(engine, "handle_error", handler)
+    event.listen(engine, "handle_error", handler, retval=True)
 
     @event.listens_for(engine, "rollback_savepoint")
     def rollback_savepoint(conn, name, context):
@@ -514,13 +517,3 @@ def register_engine(engine):
     @event.listens_for(engine, "checkin")
     def pop_exc_checkin(dbapi_conn, connection_record):
         connection_record.info.pop(ROLLBACK_CAUSE_KEY, None)
-
-
-def handle_connect_error(engine):
-    """Connect to the engine, including handle_error handlers.
-
-    The compat library now builds this into the engine.connect()
-    system as per SQLAlchemy 1.0's behavior.
-
-    """
-    return engine.connect()
