@@ -24,13 +24,11 @@ import alembic
 import alembic.autogenerate
 import alembic.migration
 import pkg_resources as pkg
-import six
 import sqlalchemy
 import sqlalchemy.exc
 import sqlalchemy.sql.expression as expr
 import sqlalchemy.types as types
 
-from oslo_db._i18n import _LE
 from oslo_db import exception as exc
 from oslo_db.sqlalchemy import provision
 from oslo_db.sqlalchemy import utils
@@ -38,15 +36,14 @@ from oslo_db.sqlalchemy import utils
 LOG = logging.getLogger(__name__)
 
 
-@six.add_metaclass(abc.ABCMeta)
-class WalkVersionsMixin(object):
+class WalkVersionsMixin(object, metaclass=abc.ABCMeta):
     """Test mixin to check upgrade and downgrade ability of migration.
 
     This is only suitable for testing of migrate_ migration scripts. An
     abstract class mixin. `INIT_VERSION`, `REPOSITORY` and `migration_api`
     attributes must be implemented in subclasses.
 
-    .. _auxiliary-dynamic-methods: Auxiliary Methods
+    .. _auxiliary-dynamic-methods:
 
     Auxiliary Methods:
 
@@ -215,7 +212,7 @@ class WalkVersionsMixin(object):
         :type version: str
         :keyword with_data: Whether to verify the absence of changes from
             migration(s) being downgraded, see
-            :ref:`auxiliary-dynamic-methods <Auxiliary Methods>`.
+            :ref:`Auxiliary Methods <auxiliary-dynamic-methods>`.
         :type with_data: Bool
         """
 
@@ -247,7 +244,7 @@ class WalkVersionsMixin(object):
         :param version: id of revision to upgrade.
         :type version: str
         :keyword with_data: Whether to verify the applied changes with data,
-            see :ref:`auxiliary-dynamic-methods <Auxiliary Methods>`.
+            see :ref:`Auxiliary Methods <auxiliary-dynamic-methods>`.
         :type with_data: Bool
         """
         # NOTE(sdague): try block is here because it's impossible to debug
@@ -270,13 +267,12 @@ class WalkVersionsMixin(object):
                 if check:
                     check(self.migrate_engine, data)
         except exc.DBMigrationError:
-            msg = _LE("Failed to migrate to version %(ver)s on engine %(eng)s")
+            msg = "Failed to migrate to version %(ver)s on engine %(eng)s"
             LOG.error(msg, {"ver": version, "eng": self.migrate_engine})
             raise
 
 
-@six.add_metaclass(abc.ABCMeta)
-class ModelsMigrationsSync(object):
+class ModelsMigrationsSync(object, metaclass=abc.ABCMeta):
     """A helper class for comparison of DB migration scripts and models.
 
     It's intended to be inherited by test cases in target projects. They have
@@ -477,30 +473,12 @@ class ModelsMigrationsSync(object):
         if isinstance(meta_col.type, sqlalchemy.Boolean):
             if meta_def is None or insp_def is None:
                 return meta_def != insp_def
+            insp_def = insp_def.strip("'")
             return not (
-                isinstance(meta_def.arg, expr.True_) and insp_def == "'1'" or
-                isinstance(meta_def.arg, expr.False_) and insp_def == "'0'"
+                isinstance(meta_def.arg, expr.True_) and insp_def == "1" or
+                isinstance(meta_def.arg, expr.False_) and insp_def == "0"
             )
 
-        impl_type = meta_col.type
-        if isinstance(impl_type, types.Variant):
-            impl_type = impl_type.load_dialect_impl(bind.dialect)
-        if isinstance(impl_type, (sqlalchemy.Integer, sqlalchemy.BigInteger)):
-            if meta_def is None or insp_def is None:
-                return meta_def != insp_def
-            return meta_def.arg != insp_def.split("'")[1]
-
-    @_compare_server_default.dispatch_for('postgresql')
-    def _compare_server_default(bind, meta_col, insp_def, meta_def):
-        if isinstance(meta_col.type, sqlalchemy.Enum):
-            if meta_def is None or insp_def is None:
-                return meta_def != insp_def
-            return insp_def != "'%s'::%s" % (meta_def.arg, meta_col.type.name)
-        elif isinstance(meta_col.type, sqlalchemy.String):
-            if meta_def is None or insp_def is None:
-                return meta_def != insp_def
-            return insp_def != "'%s'::character varying" % meta_def.arg
-
     FKInfo = collections.namedtuple('fk_info', ['constrained_columns',
                                                 'referred_table',
                                                 'referred_columns'])
