@@ -17,6 +17,7 @@
 #    under the License.
 
 import collections
+from collections import abc
 import contextlib
 import inspect as pyinspect
 import itertools
@@ -26,7 +27,6 @@ import re
 from alembic.migration import MigrationContext
 from alembic.operations import Operations
 from oslo_utils import timeutils
-import six
 import sqlalchemy
 from sqlalchemy import Boolean
 from sqlalchemy import CheckConstraint
@@ -280,8 +280,7 @@ def paginate_query(query, model, limit, sort_keys, marker=None,
 def to_list(x, default=None):
     if x is None:
         return default
-    if not isinstance(x, collections.Iterable) or \
-            isinstance(x, six.string_types):
+    if not isinstance(x, abc.Iterable) or isinstance(x, str):
         return [x]
     elif isinstance(x, list):
         return x
@@ -936,7 +935,7 @@ class DialectFunctionDispatcher(object):
     def _url_from_target(self, target):
         if isinstance(target, Connectable):
             return target.engine.url
-        elif isinstance(target, six.string_types):
+        elif isinstance(target, str):
             if "://" not in target:
                 target_url = sa_url.make_url("%s://" % target)
             else:
@@ -1027,6 +1026,7 @@ class DialectMultiFunctionDispatcher(DialectFunctionDispatcher):
                     "Return value not allowed for "
                     "multiple filtered function")
 
+
 dispatch_for_dialect = DialectFunctionDispatcher.dispatch_for_dialect
 
 
@@ -1222,12 +1222,16 @@ class NonCommittingConnectable(object):
 
     """
 
+    _nested_trans = None
+
     def __init__(self, connection):
         self.connection = connection
         self._trans = connection.begin()
         self._restart_nested()
 
     def _restart_nested(self):
+        if self._nested_trans is not None:
+            self._nested_trans.rollback()
         self._nested_trans = self.connection.begin_nested()
 
     def _dispose(self):
