@@ -9,9 +9,9 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
+from unittest import mock
 
 import alembic
-import mock
 from oslotest import base as test_base
 import sqlalchemy
 
