@@ -13,24 +13,24 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
+from unittest import mock
 
 import fixtures
-import mock
+from migrate.versioning import api as versioning_api
 from oslotest import base as test
-import six
 import sqlalchemy as sa
 import sqlalchemy.ext.declarative as sa_decl
 
 from oslo_db import exception as exc
-from oslo_db.sqlalchemy import test_base
 from oslo_db.sqlalchemy import test_migrations as migrate
+from oslo_db.tests.sqlalchemy import base as test_base
 
 
 class TestWalkVersions(test.BaseTestCase, migrate.WalkVersionsMixin):
     migration_api = mock.MagicMock()
     REPOSITORY = mock.MagicMock()
     engine = mock.MagicMock()
-    INIT_VERSION = 4
+    INIT_VERSION = versioning_api.VerNum(4)
 
     @property
     def migrate_engine(self):
@@ -46,6 +46,10 @@ class TestWalkVersions(test.BaseTestCase, migrate.WalkVersionsMixin):
         self.migration_api.db_version.assert_called_with(
             self.engine, self.REPOSITORY)
 
+    @staticmethod
+    def _fake_upgrade_boom(*args, **kwargs):
+        raise exc.DBMigrationError("boom")
+
     def test_migrate_up_fail(self):
         version = 141
         self.migration_api.db_version.return_value = version
@@ -55,9 +59,9 @@ class TestWalkVersions(test.BaseTestCase, migrate.WalkVersionsMixin):
 
         with mock.patch.object(self.migration_api,
                                'upgrade',
-                               side_effect=exc.DbMigrationError):
+                               side_effect=self._fake_upgrade_boom):
             log = self.useFixture(fixtures.FakeLogger())
-            self.assertRaises(exc.DbMigrationError, self.migrate_up, version)
+            self.assertRaises(exc.DBMigrationError, self.migrate_up, version)
             self.assertEqual(expected_output, log.output)
 
     def test_migrate_up_with_data(self):
@@ -96,7 +100,7 @@ class TestWalkVersions(test.BaseTestCase, migrate.WalkVersionsMixin):
     @mock.patch.object(migrate.WalkVersionsMixin, 'migrate_up')
     @mock.patch.object(migrate.WalkVersionsMixin, 'migrate_down')
     def test_walk_versions_all_default(self, migrate_up, migrate_down):
-        self.REPOSITORY.latest = 20
+        self.REPOSITORY.latest = versioning_api.VerNum(20)
         self.migration_api.db_version.return_value = self.INIT_VERSION
 
         self.walk_versions()
@@ -106,23 +110,25 @@ class TestWalkVersions(test.BaseTestCase, migrate.WalkVersionsMixin):
         self.migration_api.db_version.assert_called_with(
             self.engine, self.REPOSITORY)
 
-        versions = range(self.INIT_VERSION + 1, self.REPOSITORY.latest + 1)
+        versions = range(int(self.INIT_VERSION) + 1,
+                         int(self.REPOSITORY.latest) + 1)
         upgraded = [mock.call(v, with_data=True)
                     for v in versions]
-        self.assertEqual(self.migrate_up.call_args_list, upgraded)
+        self.assertEqual(upgraded, self.migrate_up.call_args_list)
 
         downgraded = [mock.call(v - 1) for v in reversed(versions)]
-        self.assertEqual(self.migrate_down.call_args_list, downgraded)
+        self.assertEqual(downgraded, self.migrate_down.call_args_list)
 
     @mock.patch.object(migrate.WalkVersionsMixin, 'migrate_up')
     @mock.patch.object(migrate.WalkVersionsMixin, 'migrate_down')
     def test_walk_versions_all_true(self, migrate_up, migrate_down):
-        self.REPOSITORY.latest = 20
+        self.REPOSITORY.latest = versioning_api.VerNum(20)
         self.migration_api.db_version.return_value = self.INIT_VERSION
 
         self.walk_versions(snake_walk=True, downgrade=True)
 
-        versions = range(self.INIT_VERSION + 1, self.REPOSITORY.latest + 1)
+        versions = range(int(self.INIT_VERSION) + 1,
+                         int(self.REPOSITORY.latest) + 1)
         upgraded = []
         for v in versions:
             upgraded.append(mock.call(v, with_data=True))
@@ -136,17 +142,18 @@ class TestWalkVersions(test.BaseTestCase, migrate.WalkVersionsMixin):
             downgraded_2.append(mock.call(v - 1))
             downgraded_2.append(mock.call(v - 1))
         downgraded = downgraded_1 + downgraded_2
-        self.assertEqual(self.migrate_down.call_args_list, downgraded)
+        self.assertEqual(downgraded, self.migrate_down.call_args_list)
 
     @mock.patch.object(migrate.WalkVersionsMixin, 'migrate_up')
     @mock.patch.object(migrate.WalkVersionsMixin, 'migrate_down')
     def test_walk_versions_true_false(self, migrate_up, migrate_down):
-        self.REPOSITORY.latest = 20
+        self.REPOSITORY.latest = versioning_api.VerNum(20)
         self.migration_api.db_version.return_value = self.INIT_VERSION
 
         self.walk_versions(snake_walk=True, downgrade=False)
 
-        versions = range(self.INIT_VERSION + 1, self.REPOSITORY.latest + 1)
+        versions = range(int(self.INIT_VERSION) + 1,
+                         int(self.REPOSITORY.latest) + 1)
 
         upgraded = []
         for v in versions:
@@ -155,23 +162,24 @@ class TestWalkVersions(test.BaseTestCase, migrate.WalkVersionsMixin):
         self.assertEqual(upgraded, self.migrate_up.call_args_list)
 
         downgraded = [mock.call(v - 1, with_data=True) for v in versions]
-        self.assertEqual(self.migrate_down.call_args_list, downgraded)
+        self.assertEqual(downgraded, self.migrate_down.call_args_list)
 
     @mock.patch.object(migrate.WalkVersionsMixin, 'migrate_up')
     @mock.patch.object(migrate.WalkVersionsMixin, 'migrate_down')
     def test_walk_versions_all_false(self, migrate_up, migrate_down):
-        self.REPOSITORY.latest = 20
+        self.REPOSITORY.latest = versioning_api.VerNum(20)
         self.migration_api.db_version.return_value = self.INIT_VERSION
 
         self.walk_versions(snake_walk=False, downgrade=False)
 
-        versions = range(self.INIT_VERSION + 1, self.REPOSITORY.latest + 1)
+        versions = range(int(self.INIT_VERSION) + 1,
+                         int(self.REPOSITORY.latest) + 1)
 
         upgraded = [mock.call(v, with_data=True) for v in versions]
         self.assertEqual(upgraded, self.migrate_up.call_args_list)
 
 
-class ModelsMigrationSyncMixin(test_base.DbTestCase):
+class ModelsMigrationSyncMixin(test_base._DbTestCase):
 
     def setUp(self):
         super(ModelsMigrationSyncMixin, self).setUp()
@@ -194,6 +202,9 @@ class ModelsMigrationSyncMixin(test_base.DbTestCase):
             sa.Column('defaulttest4', sa.Enum('first', 'second',
                                               name='testenum'),
                       server_default="first"),
+            sa.Column("defaulttest5", sa.Integer, server_default=sa.text('0')),
+            sa.Column('variant', sa.BigInteger()),
+            sa.Column('variant2', sa.BigInteger(), server_default='0'),
             sa.Column('fk_check', sa.String(36), nullable=False),
             sa.UniqueConstraint('spam', 'eggs', name='uniq_cons'),
         )
@@ -222,6 +233,12 @@ class ModelsMigrationSyncMixin(test_base.DbTestCase):
             defaulttest4 = sa.Column('defaulttest4', sa.Enum('first', 'second',
                                                              name='testenum'),
                                      server_default="first")
+            defaulttest5 = sa.Column("defaulttest5",
+                                     sa.Integer, server_default=sa.text('0'))
+            variant = sa.Column(sa.BigInteger().with_variant(
+                sa.Integer(), 'sqlite'))
+            variant2 = sa.Column(sa.BigInteger().with_variant(
+                sa.Integer(), 'sqlite'), server_default='0')
             bar = sa.Column('bar', sa.Numeric(10, 5))
 
         class ModelThatShouldNotBeCompared(BASE):
@@ -245,6 +262,53 @@ class ModelsMigrationSyncMixin(test_base.DbTestCase):
         else:
             return True
 
+    def _test_models_not_sync_filtered(self):
+        self.metadata_migrations.clear()
+        sa.Table(
+            'table', self.metadata_migrations,
+            sa.Column('fk_check', sa.String(36), nullable=False),
+            sa.PrimaryKeyConstraint('fk_check'),
+            mysql_engine='InnoDB'
+        )
+
+        sa.Table(
+            'testtbl', self.metadata_migrations,
+            sa.Column('id', sa.Integer, primary_key=True),
+            sa.Column('spam', sa.String(8), nullable=True),
+            sa.Column('eggs', sa.DateTime),
+            sa.Column('foo', sa.Boolean,
+                      server_default=sa.sql.expression.false()),
+            sa.Column('bool_wo_default', sa.Boolean, unique=True),
+            sa.Column('bar', sa.BigInteger),
+            sa.Column('defaulttest', sa.Integer, server_default='7'),
+            sa.Column('defaulttest2', sa.String(8), server_default=''),
+            sa.Column('defaulttest3', sa.String(5), server_default="fake"),
+            sa.Column('defaulttest4',
+                      sa.Enum('first', 'second', name='testenum'),
+                      server_default="first"),
+            sa.Column("defaulttest5", sa.Integer, server_default=sa.text('0')),
+            sa.Column('fk_check', sa.String(36), nullable=False),
+            sa.UniqueConstraint('spam', 'foo', name='uniq_cons'),
+            sa.ForeignKeyConstraint(['fk_check'], ['table.fk_check']),
+            mysql_engine='InnoDB'
+        )
+
+        with mock.patch.object(self, 'filter_metadata_diff') as filter_mock:
+            def filter_diffs(diffs):
+                # test filter returning only constraint related diffs
+                return [
+                    diff
+                    for diff in diffs
+                    if 'constraint' in diff[0]
+                ]
+            filter_mock.side_effect = filter_diffs
+
+            msg = str(self.assertRaises(AssertionError, self.test_models_sync))
+            self.assertNotIn('defaulttest', msg)
+            self.assertNotIn('defaulttest3', msg)
+            self.assertNotIn('remove_fk', msg)
+            self.assertIn('constraint', msg)
+
     def _test_models_not_sync(self):
         self.metadata_migrations.clear()
         sa.Table(
@@ -268,14 +332,15 @@ class ModelsMigrationSyncMixin(test_base.DbTestCase):
             sa.Column('defaulttest4',
                       sa.Enum('first', 'second', name='testenum'),
                       server_default="first"),
+            sa.Column("defaulttest5", sa.Integer, server_default=sa.text('0')),
+            sa.Column('variant', sa.String(10)),
             sa.Column('fk_check', sa.String(36), nullable=False),
             sa.UniqueConstraint('spam', 'foo', name='uniq_cons'),
             sa.ForeignKeyConstraint(['fk_check'], ['table.fk_check']),
             mysql_engine='InnoDB'
         )
 
-        msg = six.text_type(self.assertRaises(AssertionError,
-                                              self.test_models_sync))
+        msg = str(self.assertRaises(AssertionError, self.test_models_sync))
         # NOTE(I159): Check mentioning of the table and columns.
         # The log is invalid json, so we can't parse it and check it for
         # full compliance. We have no guarantee of the log items ordering,
@@ -291,25 +356,32 @@ class ModelsMigrationSyncMixin(test_base.DbTestCase):
         self.assertIn('defaulttest', msg)
         self.assertIn('defaulttest3', msg)
         self.assertIn('remove_fk', msg)
+        self.assertIn('variant', msg)
 
 
 class ModelsMigrationsSyncMysql(ModelsMigrationSyncMixin,
                                 migrate.ModelsMigrationsSync,
-                                test_base.MySQLOpportunisticTestCase):
+                                test_base._MySQLOpportunisticTestCase):
 
     def test_models_not_sync(self):
         self._test_models_not_sync()
 
+    def test_models_not_sync_filtered(self):
+        self._test_models_not_sync_filtered()
+
 
 class ModelsMigrationsSyncPsql(ModelsMigrationSyncMixin,
                                migrate.ModelsMigrationsSync,
-                               test_base.PostgreSQLOpportunisticTestCase):
+                               test_base._PostgreSQLOpportunisticTestCase):
 
     def test_models_not_sync(self):
         self._test_models_not_sync()
 
+    def test_models_not_sync_filtered(self):
+        self._test_models_not_sync_filtered()
 
-class TestOldCheckForeignKeys(test_base.DbTestCase):
+
+class TestOldCheckForeignKeys(test_base._DbTestCase):
     def setUp(self):
         super(TestOldCheckForeignKeys, self).setUp()
 
@@ -441,7 +513,7 @@ class TestOldCheckForeignKeys(test_base.DbTestCase):
             )
             for cmd, fk, tname, fk_info in diffs
         ]
-        self.assertEqual(diffs, compare_to)
+        self.assertEqual(compare_to, diffs)
 
     def test_fk_added(self):
         self._fk_added_fixture()
@@ -487,10 +559,10 @@ class TestOldCheckForeignKeys(test_base.DbTestCase):
 
 
 class PGTestOldCheckForeignKeys(
-        TestOldCheckForeignKeys, test_base.PostgreSQLOpportunisticTestCase):
+        TestOldCheckForeignKeys, test_base._PostgreSQLOpportunisticTestCase):
     pass
 
 
 class MySQLTestOldCheckForeignKeys(
-        TestOldCheckForeignKeys, test_base.MySQLOpportunisticTestCase):
+        TestOldCheckForeignKeys, test_base._MySQLOpportunisticTestCase):
     pass
