@@ -19,12 +19,11 @@
 
 import logging
 import os
+from unittest import mock
 
 import fixtures
-import mock
 from oslo_config import cfg
 from oslotest import base as oslo_test
-import six
 import sqlalchemy
 from sqlalchemy import Column, MetaData, Table
 from sqlalchemy.engine import url
@@ -52,7 +51,7 @@ class RegexpTable(BASE, models.ModelBase):
     bar = Column(String(255))
 
 
-class RegexpFilterTestCase(test_base.DbTestCase):
+class RegexpFilterTestCase(test_base._DbTestCase):
 
     def setUp(self):
         super(RegexpFilterTestCase, self).setUp()
@@ -90,7 +89,7 @@ class RegexpFilterTestCase(test_base.DbTestCase):
         self._test_regexp_filter(u'♦', [])
 
 
-class SQLiteSavepointTest(test_base.DbTestCase):
+class SQLiteSavepointTest(test_base._DbTestCase):
     def setUp(self):
         super(SQLiteSavepointTest, self).setUp()
         meta = MetaData()
@@ -213,7 +212,80 @@ class FakeDB2Engine(object):
         pass
 
 
-class MySQLDefaultModeTestCase(test_base.MySQLOpportunisticTestCase):
+class QueryParamTest(test_base.DbTestCase):
+    def _fixture(self):
+        from sqlalchemy import create_engine
+
+        def _mock_create_engine(*arg, **kw):
+            return create_engine("sqlite://")
+
+        return mock.patch(
+            "oslo_db.sqlalchemy.engines.sqlalchemy.create_engine",
+            side_effect=_mock_create_engine)
+
+    def test_add_assorted_params(self):
+        with self._fixture() as ce:
+            engines.create_engine(
+                "mysql+pymysql://foo:bar@bat",
+                connection_parameters="foo=bar&bat=hoho&bat=param2")
+
+        self.assertEqual(
+            ce.mock_calls[0][1][0].query,
+            {'bat': ['hoho', 'param2'], 'foo': 'bar'}
+        )
+
+    def test_add_no_params(self):
+        with self._fixture() as ce:
+            engines.create_engine(
+                "mysql+pymysql://foo:bar@bat")
+
+        self.assertEqual(
+            ce.mock_calls[0][1][0].query,
+            {}
+        )
+
+    def test_combine_params(self):
+        with self._fixture() as ce:
+            engines.create_engine(
+                "mysql+pymysql://foo:bar@bat/"
+                "?charset=utf8&param_file=tripleo.cnf",
+                connection_parameters="plugin=sqlalchemy_collectd&"
+                                      "collectd_host=127.0.0.1&"
+                                      "bind_host=192.168.1.5")
+
+        self.assertEqual(
+            ce.mock_calls[0][1][0].query,
+            {
+                'bind_host': '192.168.1.5',
+                'charset': 'utf8',
+                'collectd_host': '127.0.0.1',
+                'param_file': 'tripleo.cnf',
+                'plugin': 'sqlalchemy_collectd'
+            }
+        )
+
+    def test_combine_multi_params(self):
+        with self._fixture() as ce:
+            engines.create_engine(
+                "mysql+pymysql://foo:bar@bat/"
+                "?charset=utf8&param_file=tripleo.cnf&plugin=connmon",
+                connection_parameters="plugin=sqlalchemy_collectd&"
+                                      "collectd_host=127.0.0.1&"
+                                      "bind_host=192.168.1.5")
+
+        self.assertEqual(
+            ce.mock_calls[0][1][0].query,
+            {
+                'bind_host': '192.168.1.5',
+                'charset': 'utf8',
+                'collectd_host': '127.0.0.1',
+                'param_file': 'tripleo.cnf',
+                'plugin': ['connmon', 'sqlalchemy_collectd']
+            }
+        )
+
+
+class MySQLDefaultModeTestCase(test_base._MySQLOpportunisticTestCase):
     def test_default_is_traditional(self):
         with self.engine.connect() as conn:
             sql_mode = conn.execute(
@@ -223,7 +295,7 @@ class MySQLDefaultModeTestCase(test_base.MySQLOpportunisticTestCase):
         self.assertIn("TRADITIONAL", sql_mode)
 
 
-class MySQLModeTestCase(test_base.MySQLOpportunisticTestCase):
+class MySQLModeTestCase(test_base._MySQLOpportunisticTestCase):
 
     def __init__(self, *args, **kwargs):
         super(MySQLModeTestCase, self).__init__(*args, **kwargs)
@@ -357,6 +429,7 @@ class EngineFacadeTestCase(oslo_test.BaseTestCase):
             thread_checkin=mock.ANY,
             json_serializer=None,
             json_deserializer=None,
+            connection_parameters='',
             logging_name=mock.ANY,
         )
         get_maker.assert_called_once_with(engine=create_engine(),
@@ -438,7 +511,7 @@ class SQLiteConnectTest(oslo_test.BaseTestCase):
         )
 
 
-class MysqlConnectTest(test_base.MySQLOpportunisticTestCase):
+class MysqlConnectTest(test_base._MySQLOpportunisticTestCase):
 
     def _fixture(self, sql_mode):
         return session.create_engine(self.engine.url, mysql_sql_mode=sql_mode)
@@ -609,12 +682,8 @@ class CreateEngineTest(oslo_test.BaseTestCase):
         self.assertNotIn('poolclass', self.args)
 
     def _test_mysql_connect_args_default(self, connect_args):
-        if six.PY3:
-            self.assertEqual({'charset': 'utf8', 'use_unicode': 1},
-                             connect_args)
-        else:
-            self.assertEqual({'charset': 'utf8', 'use_unicode': 0},
-                             connect_args)
+        self.assertEqual({'charset': 'utf8', 'use_unicode': 1},
+                         connect_args)
 
     def test_mysql_connect_args_default(self):
         engines._init_connection_args(
@@ -716,7 +785,7 @@ class CreateEngineTest(oslo_test.BaseTestCase):
         )
 
 
-class ProcessGuardTest(test_base.DbTestCase):
+class ProcessGuardTest(test_base._DbTestCase):
     def test_process_guard(self):
         self.engine.dispose()
 
@@ -744,7 +813,7 @@ class ProcessGuardTest(test_base.DbTestCase):
         self.assertEqual(new_dbapi_id, newer_dbapi_id)
 
 
-class PatchStacktraceTest(test_base.DbTestCase):
+class PatchStacktraceTest(test_base._DbTestCase):
 
     def test_trace(self):
         engine = self.engine
